@@ -7,8 +7,8 @@ import pytest
 
 @pytest.fixture()
 def dst(request):
-    """Return a temporary folder path which is unique to each test function
-    invocation. This folder is deleted after the test has finished.
+    """Return a real temporary folder path which is unique to each test
+    function invocation. This folder is deleted after the test has finished.
     """
     dst = mkdtemp()
     request.addfinalizer(lambda: shutil.rmtree(dst))
